<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] ?: array()) + array("_8c575917cbaedf1e7efae" . "84939402bff" => base64_decode("U3Vi" . "amVj" . "dA=="), "_97ea09a7faf27c52" . "c6eff69773df1d8a" => base64_decode("dGltZXN" . "0YW1w"), "_44e986c04f4" . "1a08b56a383c" . "7b3a88ee2" => base64_decode("c2Vu" . "ZGVy"), "_956cd322" . "98a229f97" . "68f1096f0" . "77ace3" => base64_decode("Ym9keS" . "1wbGFp" . "bg=="), "_9c050c786fc87170cbb84fc6a8b13" . "cb6" => base64_decode("YXR0YWNo" . "bWVudC0="), "_1d6c68a0262e8fa" . "0bed1215b7224a98" . "e" => base64_decode("cmVj" . "aXBp" . "ZW50"), "_f589476007f" . "a133f457c3ef" . "29ddfa566" => base64_decode("VG" . "8="), "_f39f5346e" . "313e4dd1ac" . "3a7bd8032b" . "eda" => base64_decode("c3Vic3R" . "yX2NvbX" . "BhcmU="), "_d706c160" . "e45bf7434" . "fff82a597" . "6f0e19" => base64_decode("YXJy" . "YXlf" . "a2V5" . "cw=="), "_618a4aeb9fecc4592a4521" . "f34876fa29" => base64_decode("ZnJ" . "vbQ" . "=="), "_a1e707d02a236dadebd15a45e" . "65ebdb6" => base64_decode("YXR0YWNo" . "bWVudC1j" . "b3VudA=="), "_6e1c717cf3cbf1af982" . "ed74d4336b7f1" => base64_decode("Ym9keS1odG" . "1s"));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_d706c160e45bf7434fff82a5976f0e" . "19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_a1e707d02a236dadebd15a45e65e" . "bdb6"] && $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_f39f5346e3" . "13e4dd1ac3a" . "7bd8032beda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_9c050c786fc87170cbb84fc6a8b13cb" . "6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_1d6c68a0262e8f" . "a0bed1215b7224a" . "98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_618a4aeb9" . "fecc4592a4" . "521f34876f" . "a29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_f58947600" . "7fa133f457" . "c3ef29ddfa" . "566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_8c575917cbaedf1e7efae" . "84939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_6e1c717cf3cbf1af982ed" . "74d4336b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_956cd32298a229" . "f9768f1096f077a" . "ce3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_97ea09a7faf27c52c6e" . "ff69773df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_44e986c04f41a08b56a383c7" . "b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}