<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] ?: array()) + array("_5d40a2cf1c525fb252bf5599e339fd" . "d0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvam" . "VjdCB3YXMgaWRlbnRpZmllZCBm" . "b3IgbWFpbDsgc3ViamVjdCAn"), "_67a0d624aeb" . "cceb0abd5ce5" . "6a53ff06f" => base64_decode("ZG" . "F0" . "ZQ" . "=="), "_618a4aeb9fecc4592a4521f34876fa2" . "9" => base64_decode("Zn" . "Jv" . "bQ" . "=="), "_f65681696" . "1e85738061" . "41c558b184" . "fe2" => base64_decode("c3ViamVjdA=" . "="), "_c35473364fa7a050299058f332" . "ec29c1" => base64_decode("ZXhjZXB0aW9" . "u"), "_03b1f0cee835582d1158dce267" . "8b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUg" . "bWFpbCByZWNlaXZlZCBzdWJzY3Jp" . "YmVy"), "_bfda889b74ea561b" . "14325e30e7d75426" => base64_decode("Ym9ke" . "V9odG" . "1s"), "_a3d82c5df38e194c9c73e3ccb422" . "3bbc" => base64_decode("ZW1haWxfZGF0YQ=" . "="), "_376d30c4085735" . "7a4d4cbb1ffaa25" . "817" => base64_decode("d" . "G" . "8" . "="), "projec" . "t_id" => base64_decode("cHJv" . "amVj" . "dF9p" . "ZA=="), "_460e1aeb3113a1676ce59a8" . "f40431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1h" . "aWwgZm9yIGluZm9jYXB0dXJlIHBy" . "b2plY3Q="), "_ced92d7b391285c8a26846" . "f1f4bd3128" => base64_decode("Ym9keV90ZX" . "h0"), "_9b16fa2683095e67d7c8b2" . "65a8081d0b" => base64_decode("TWFpbFJlY2VpdmVkRXZlbnR" . "SZWNlaXZlcg=="), "_e608e5b5c4c34a67b" . "a97ef84c1e16199" => base64_decode("J" . "w" . "=" . "="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_9b16fa2683095e" . "67d7c8b265a8081" . "d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_03b1f0cee835582d1158dce" . "2678b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_5d40a2cf" . "1c525fb25" . "2bf5599e3" . "39fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_e608e5b5c4c34a" . "67ba97ef84c1e16" . "199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_618a4aeb9fecc4592a4" . "521f34876fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_376d30c4085735" . "7a4d4cbb1ffaa25" . "817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_f656816961e8573806141c558b184" . "fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_ced92d7b" . "391285c8a" . "26846f1f4" . "bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_bfda889b74ea" . "561b14325e30e" . "7d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_67a0d624aebcceb0abd" . "5ce56a53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_460e1aeb3113a167" . "6ce59a8f40431d5c"], [$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["project_" . "id"] => $project->GetId(), $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_a3d82c5d" . "f38e194c9" . "c73e3ccb4" . "223bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_c35473364fa7" . "a050299058f33" . "2ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}